/// <reference path="./custom.d.ts" />
// tslint:disable
/**
 * Astronomy - A Weather Source API
 * Daily and hourly astronomical data for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. The Weather Source Astronomy API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 *
 * NOTE: This file is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the file manually.
 */

import * as url from "url";
import * as isomorphicFetch from "isomorphic-fetch";
import { Configuration } from "./configuration";

const BASE_PATH = "https://astronomy.weathersourceapis.com/v2".replace(/\/+$/, "");

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
    csv: ",",
    ssv: " ",
    tsv: "\t",
    pipes: "|",
};

/**
 *
 * @export
 * @interface FetchAPI
 */
export interface FetchAPI {
    (url: string, init?: any): Promise<Response>;
}

/**
 *
 * @export
 * @interface FetchArgs
 */
export interface FetchArgs {
    url: string;
    options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
    protected configuration: Configuration;

    constructor(configuration?: Configuration, protected basePath: string = BASE_PATH, protected fetch: FetchAPI = isomorphicFetch) {
        if (configuration) {
            this.configuration = configuration;
            this.basePath = configuration.basePath || this.basePath;
        }
    }
};

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
    name: "RequiredError"
    constructor(public field: string, msg?: string) {
        super(msg);
    }
}

/**
 * Time of the beginning of astronomical twilight before sunrise formatted RFC 3339.
 * @export
 */
export type AstroRise = Date
/**
 * Time of the end of astronomical twilight after sunset formatted RFC 3339.
 * @export
 */
export type AstroSet = Date
/**
 * An array of daily astronomy objects.
 * @export
 */
export type AstronomyDayArr = Array<AstronomyDayObj>
/**
 * A daily astronomy object.
 * @export
 * @interface AstronomyDayObj
 */
export interface AstronomyDayObj {
    /**
     * 
     * @type {string}
     * @memberof AstronomyDayObj
     */
    date: string;
    /**
     * 
     * @type {SunDistance}
     * @memberof AstronomyDayObj
     */
    sunDistance?: SunDistance;
    /**
     * 
     * @type {SunRadius}
     * @memberof AstronomyDayObj
     */
    sunRadius?: SunRadius;
    /**
     * 
     * @type {SunTransit}
     * @memberof AstronomyDayObj
     */
    sunTransit?: SunTransit;
    /**
     * 
     * @type {Sunrise}
     * @memberof AstronomyDayObj
     */
    sunrise?: Sunrise;
    /**
     * 
     * @type {Sunset}
     * @memberof AstronomyDayObj
     */
    sunset?: Sunset;
    /**
     * 
     * @type {CivilRise}
     * @memberof AstronomyDayObj
     */
    civilRise?: CivilRise;
    /**
     * 
     * @type {CivilSet}
     * @memberof AstronomyDayObj
     */
    civilSet?: CivilSet;
    /**
     * 
     * @type {NauticalRise}
     * @memberof AstronomyDayObj
     */
    nauticalRise?: NauticalRise;
    /**
     * 
     * @type {NauticalSet}
     * @memberof AstronomyDayObj
     */
    nauticalSet?: NauticalSet;
    /**
     * 
     * @type {AstroRise}
     * @memberof AstronomyDayObj
     */
    astroRise?: AstroRise;
    /**
     * 
     * @type {AstroSet}
     * @memberof AstronomyDayObj
     */
    astroSet?: AstroSet;
    /**
     * 
     * @type {MoonDistance}
     * @memberof AstronomyDayObj
     */
    moonDistance?: MoonDistance;
    /**
     * 
     * @type {MoonRadius}
     * @memberof AstronomyDayObj
     */
    moonRadius?: MoonRadius;
    /**
     * 
     * @type {Moonrise}
     * @memberof AstronomyDayObj
     */
    moonrise?: Moonrise;
    /**
     * 
     * @type {Moonset}
     * @memberof AstronomyDayObj
     */
    moonset?: Moonset;
    /**
     * 
     * @type {MoonPhase}
     * @memberof AstronomyDayObj
     */
    moonPhase?: MoonPhase;
    /**
     * 
     * @type {MoonIllum}
     * @memberof AstronomyDayObj
     */
    moonIllum?: MoonIllum;
    /**
     * 
     * @type {MoonAge}
     * @memberof AstronomyDayObj
     */
    moonAge?: MoonAge;
}
/**
 * Daily Designated Market Area astronomical object
 * @export
 * @interface AstronomyDmaDayObj
 */
export interface AstronomyDmaDayObj {
    /**
     * 
     * @type {DmaObj}
     * @memberof AstronomyDmaDayObj
     */
    location: DmaObj;
    /**
     * 
     * @type {DateRangeObj}
     * @memberof AstronomyDmaDayObj
     */
    dateRange: DateRangeObj;
    /**
     * 
     * @type {FieldListDayObj}
     * @memberof AstronomyDmaDayObj
     */
    fieldList: FieldListDayObj;
    /**
     * 
     * @type {AstronomyDayArr}
     * @memberof AstronomyDmaDayObj
     */
    astronomy: AstronomyDayArr;
}
/**
 * Hourly Designated Market Area astronomical object
 * @export
 * @interface AstronomyDmaHourObj
 */
export interface AstronomyDmaHourObj {
    /**
     * 
     * @type {DmaObj}
     * @memberof AstronomyDmaHourObj
     */
    location: DmaObj;
    /**
     * 
     * @type {TimestampRangeObj}
     * @memberof AstronomyDmaHourObj
     */
    timestampRange: TimestampRangeObj;
    /**
     * 
     * @type {FieldListHourObj}
     * @memberof AstronomyDmaHourObj
     */
    fieldList: FieldListHourObj;
    /**
     * 
     * @type {AstronomyHourArr}
     * @memberof AstronomyDmaHourObj
     */
    astronomy: AstronomyHourArr;
}
/**
 * An array of hourly astronomy objects.
 * @export
 */
export type AstronomyHourArr = Array<AstronomyHourObj>
/**
 * An hourly astronomy object.
 * @export
 * @interface AstronomyHourObj
 */
export interface AstronomyHourObj {
    /**
     * 
     * @type {Timestamp}
     * @memberof AstronomyHourObj
     */
    timestamp: Timestamp;
    /**
     * 
     * @type {SunDistance}
     * @memberof AstronomyHourObj
     */
    sunDistance?: SunDistance;
    /**
     * 
     * @type {SunRadius}
     * @memberof AstronomyHourObj
     */
    sunRadius?: SunRadius;
    /**
     * 
     * @type {SunAzimuth}
     * @memberof AstronomyHourObj
     */
    sunAzimuth?: SunAzimuth;
    /**
     * 
     * @type {SunElevation}
     * @memberof AstronomyHourObj
     */
    sunElevation?: SunElevation;
    /**
     * 
     * @type {MoonDistance}
     * @memberof AstronomyHourObj
     */
    moonDistance?: MoonDistance;
    /**
     * 
     * @type {MoonRadius}
     * @memberof AstronomyHourObj
     */
    moonRadius?: MoonRadius;
    /**
     * 
     * @type {MoonAzimuth}
     * @memberof AstronomyHourObj
     */
    moonAzimuth?: MoonAzimuth;
    /**
     * 
     * @type {MoonElevation}
     * @memberof AstronomyHourObj
     */
    moonElevation?: MoonElevation;
    /**
     * 
     * @type {MoonPhase}
     * @memberof AstronomyHourObj
     */
    moonPhase?: MoonPhase;
    /**
     * 
     * @type {MoonIllum}
     * @memberof AstronomyHourObj
     */
    moonIllum?: MoonIllum;
    /**
     * 
     * @type {MoonAge}
     * @memberof AstronomyHourObj
     */
    moonAge?: MoonAge;
}
/**
 * Daily OnPoint™ astronomical object
 * @export
 * @interface AstronomyOnpointDayObj
 */
export interface AstronomyOnpointDayObj {
    /**
     * 
     * @type {OnpointObj}
     * @memberof AstronomyOnpointDayObj
     */
    location: OnpointObj;
    /**
     * 
     * @type {DateRangeObj}
     * @memberof AstronomyOnpointDayObj
     */
    dateRange: DateRangeObj;
    /**
     * 
     * @type {FieldListDayObj}
     * @memberof AstronomyOnpointDayObj
     */
    fieldList: FieldListDayObj;
    /**
     * 
     * @type {AstronomyDayArr}
     * @memberof AstronomyOnpointDayObj
     */
    astronomy: AstronomyDayArr;
}
/**
 * Hourly OnPoint™ astronomical object
 * @export
 * @interface AstronomyOnpointHourObj
 */
export interface AstronomyOnpointHourObj {
    /**
     * 
     * @type {OnpointObj}
     * @memberof AstronomyOnpointHourObj
     */
    location: OnpointObj;
    /**
     * 
     * @type {TimestampRangeObj}
     * @memberof AstronomyOnpointHourObj
     */
    timestampRange: TimestampRangeObj;
    /**
     * 
     * @type {FieldListHourObj}
     * @memberof AstronomyOnpointHourObj
     */
    fieldList: FieldListHourObj;
    /**
     * 
     * @type {AstronomyHourArr}
     * @memberof AstronomyOnpointHourObj
     */
    astronomy: AstronomyHourArr;
}
/**
 * Daily Latitude/Longitude astronomical object
 * @export
 * @interface AstronomyPointDayObj
 */
export interface AstronomyPointDayObj {
    /**
     * 
     * @type {PointObj}
     * @memberof AstronomyPointDayObj
     */
    location: PointObj;
    /**
     * 
     * @type {DateRangeObj}
     * @memberof AstronomyPointDayObj
     */
    dateRange: DateRangeObj;
    /**
     * 
     * @type {FieldListDayObj}
     * @memberof AstronomyPointDayObj
     */
    fieldList: FieldListDayObj;
    /**
     * 
     * @type {AstronomyDayArr}
     * @memberof AstronomyPointDayObj
     */
    astronomy: AstronomyDayArr;
}
/**
 * Hourly Latitude/Longitude astronomical object
 * @export
 * @interface AstronomyPointHourObj
 */
export interface AstronomyPointHourObj {
    /**
     * 
     * @type {PointObj}
     * @memberof AstronomyPointHourObj
     */
    location: PointObj;
    /**
     * 
     * @type {TimestampRangeObj}
     * @memberof AstronomyPointHourObj
     */
    timestampRange: TimestampRangeObj;
    /**
     * 
     * @type {FieldListHourObj}
     * @memberof AstronomyPointHourObj
     */
    fieldList: FieldListHourObj;
    /**
     * 
     * @type {AstronomyHourArr}
     * @memberof AstronomyPointHourObj
     */
    astronomy: AstronomyHourArr;
}
/**
 * Daily Postcode astronomical object
 * @export
 * @interface AstronomyPostcodeDayObj
 */
export interface AstronomyPostcodeDayObj {
    /**
     * 
     * @type {PostcodeObj}
     * @memberof AstronomyPostcodeDayObj
     */
    location: PostcodeObj;
    /**
     * 
     * @type {DateRangeObj}
     * @memberof AstronomyPostcodeDayObj
     */
    dateRange: DateRangeObj;
    /**
     * 
     * @type {FieldListDayObj}
     * @memberof AstronomyPostcodeDayObj
     */
    fieldList: FieldListDayObj;
    /**
     * 
     * @type {AstronomyDayArr}
     * @memberof AstronomyPostcodeDayObj
     */
    astronomy: AstronomyDayArr;
}
/**
 * Hourly Postcode astronomical object
 * @export
 * @interface AstronomyPostcodeHourObj
 */
export interface AstronomyPostcodeHourObj {
    /**
     * 
     * @type {PostcodeObj}
     * @memberof AstronomyPostcodeHourObj
     */
    location: PostcodeObj;
    /**
     * 
     * @type {TimestampRangeObj}
     * @memberof AstronomyPostcodeHourObj
     */
    timestampRange: TimestampRangeObj;
    /**
     * 
     * @type {FieldListHourObj}
     * @memberof AstronomyPostcodeHourObj
     */
    fieldList: FieldListHourObj;
    /**
     * 
     * @type {AstronomyHourArr}
     * @memberof AstronomyPostcodeHourObj
     */
    astronomy: AstronomyHourArr;
}
/**
 * A list of OnPoint™ points related to the location
 * @export
 */
export type BoundingPoints = Array<BoundingPointsInner>
/**
 * 
 * @export
 * @interface BoundingPointsInner
 */
export interface BoundingPointsInner {
    /**
     * 
     * @type {OnpointId}
     * @memberof BoundingPointsInner
     */
    onpointId: OnpointId;
    /**
     * 
     * @type {Latitude}
     * @memberof BoundingPointsInner
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof BoundingPointsInner
     */
    longitude: Longitude;
    /**
     * 
     * @type {Grid}
     * @memberof BoundingPointsInner
     */
    grid: Grid;
    /**
     * 
     * @type {Distance}
     * @memberof BoundingPointsInner
     */
    distance: Distance;
    /**
     * 
     * @type {Elevation}
     * @memberof BoundingPointsInner
     */
    elevation: Elevation;
}
/**
 * Time of the beginning of civil twilight before sunrise formatted RFC 3339.
 * @export
 */
export type CivilRise = Date
/**
 * Time of the end of civil twilight after sunset formatted RFC 3339.
 * @export
 */
export type CivilSet = Date
/**
 * An [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
 * @export
 */
export type CountryCode = string
/**
 * A common country name.
 * @export
 */
export type CountryName = string
/**
 * A date formatted as an RFC3339 date value.
 * @export
 */
export type Date = string
/**
 * An end date for a date range formatted as an RFC3339 date value.
 * @export
 */
export type DateEnd = string
/**
 * A date range object.
 * @export
 * @interface DateRangeObj
 */
export interface DateRangeObj {
    /**
     * 
     * @type {DateStart}
     * @memberof DateRangeObj
     */
    dateStart: DateStart;
    /**
     * 
     * @type {DateEnd}
     * @memberof DateRangeObj
     */
    dateEnd: DateEnd;
}
/**
 * A start date for a date range formatted as an RFC3339 date value.
 * @export
 */
export type DateStart = string
/**
 * A distance from the provided point in miles.
 * @export
 */
export type Distance = number
/**
 * The difference in population for the whole Designated Market Area and the population for the postcode represented by this sample point.
 * @export
 */
export type DistancePop = number
/**
 * A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
 * @export
 */
export type DmaId = number
/**
 * A Designated Market Area name.
 * @export
 */
export type DmaName = string
/**
 * A Designated Market Area location metadata object
 * @export
 * @interface DmaObj
 */
export interface DmaObj {
    /**
     * 
     * @type {DmaId}
     * @memberof DmaObj
     */
    dmaId: DmaId;
    /**
     * 
     * @type {DmaName}
     * @memberof DmaObj
     */
    dmaName: DmaName;
    /**
     * 
     * @type {Timezone}
     * @memberof DmaObj
     */
    timezone: Timezone;
    /**
     * 
     * @type {Population}
     * @memberof DmaObj
     */
    population: Population;
    /**
     * 
     * @type {CountryCode}
     * @memberof DmaObj
     */
    countryCode: CountryCode;
    /**
     * 
     * @type {CountryName}
     * @memberof DmaObj
     */
    countryName: CountryName;
    /**
     * 
     * @type {SamplePoints}
     * @memberof DmaObj
     */
    samplePoints: SamplePoints;
    /**
     * 
     * @type {Grid}
     * @memberof DmaObj
     */
    grid: Grid;
}
/**
 * The elevation above sea level of a location in meters
 * @export
 */
export type Elevation = number
/**
 * 
 * @export
 * @interface ErrorObj
 */
export interface ErrorObj {
    /**
     * 
     * @type {number}
     * @memberof ErrorObj
     */
    errorCode?: number;
    /**
     * 
     * @type {string}
     * @memberof ErrorObj
     */
    errorMessage?: string;
}
/**
 * A list of returned field names the associated units.
 * @export
 * @interface FieldListDayObj
 */
export interface FieldListDayObj {
    /**
     * 
     * @type {Fields}
     * @memberof FieldListDayObj
     */
    fields: Fields;
}
/**
 * A list of returned field names the associated units.
 * @export
 * @interface FieldListHourObj
 */
export interface FieldListHourObj {
    /**
     * 
     * @type {Fields}
     * @memberof FieldListHourObj
     */
    fields: Fields;
}
/**
 * 
 * @export
 * @interface Fields
 */
export interface Fields extends null<String, string> {
    [key: string]: string;

}
/**
 * The OnPoint™ grid on which the resource exists.
 * @export
 * @enum {string}
 */
export enum Grid {
    GLOBALGRID = <any> 'GLOBAL_GRID',
    NORTHAMERICAGRID = <any> 'NORTH_AMERICA_GRID'
}
/**
 * A latitude value between -90° and 90°.
 * @export
 */
export type Latitude = number
/**
 * A longitude value between -180° (West) and 180° (East).
 * @export
 */
export type Longitude = number
/**
 * Age in days of the Moon in the Synodic month.
 * @export
 */
export type MoonAge = number
/**
 * Azimuth of the Moon in degrees, angle along the local horizon measured clockwise from due north.
 * @export
 */
export type MoonAzimuth = number
/**
 * Distance from Earth to Moon in miles (imperial) or km (metric, si).
 * @export
 */
export type MoonDistance = number
/**
 * Altitude of the Moon in degrees, angle between the horizon and the center of the Moon's disc.
 * @export
 */
export type MoonElevation = number
/**
 * Portion of the Moon illuminated by the Sun as a percentage.
 * @export
 */
export type MoonIllum = number
/**
 * The Moon Phase as a string.
 * @export
 * @enum {string}
 */
export enum MoonPhase {
    NewMoon = <any> 'New Moon',
    FirstQuarter = <any> 'First Quarter',
    FullMoon = <any> 'Full Moon',
    LastQuarter = <any> 'Last Quarter',
    WaxingCrescent = <any> 'Waxing Crescent',
    WaxingGibbous = <any> 'Waxing Gibbous',
    WaningGibbous = <any> 'Waning Gibbous',
    WaningCrescent = <any> 'Waning Crescent'
}
/**
 * Apparent angular radius of the Moon in degrees.
 * @export
 */
export type MoonRadius = number
/**
 * Time of moonrise formatted RFC 3339.
 * @export
 */
export type Moonrise = Date
/**
 * Time of moonset formatted RFC 3339.
 * @export
 */
export type Moonset = Date
/**
 * Time of the beginning of nautical twilight before sunrise formatted RFC 3339.
 * @export
 */
export type NauticalRise = Date
/**
 * Time of the end of nautical twilight after sunset formatted RFC 3339.
 * @export
 */
export type NauticalSet = Date
/**
 * An OnPoint™ ID.
 * @export
 */
export type OnpointId = number
/**
 * An OnPoint™ point location metadata object
 * @export
 * @interface OnpointObj
 */
export interface OnpointObj {
    /**
     * 
     * @type {OnpointId}
     * @memberof OnpointObj
     */
    onpointId: OnpointId;
    /**
     * 
     * @type {Latitude}
     * @memberof OnpointObj
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof OnpointObj
     */
    longitude: Longitude;
    /**
     * 
     * @type {Timezone}
     * @memberof OnpointObj
     */
    timezone: Timezone;
    /**
     * 
     * @type {CountryCode}
     * @memberof OnpointObj
     */
    countryCode?: CountryCode;
    /**
     * 
     * @type {CountryName}
     * @memberof OnpointObj
     */
    countryName?: CountryName;
    /**
     * 
     * @type {SubdivCode}
     * @memberof OnpointObj
     */
    subdivCode?: SubdivCode;
    /**
     * 
     * @type {SubdivName}
     * @memberof OnpointObj
     */
    subdivName?: SubdivName;
    /**
     * 
     * @type {Grid}
     * @memberof OnpointObj
     */
    grid: Grid;
    /**
     * 
     * @type {Elevation}
     * @memberof OnpointObj
     */
    elevation: Elevation;
}
/**
 * Metadata object for a postcode
 * @export
 * @interface PointObj
 */
export interface PointObj {
    /**
     * 
     * @type {Latitude}
     * @memberof PointObj
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof PointObj
     */
    longitude: Longitude;
    /**
     * 
     * @type {Timezone}
     * @memberof PointObj
     */
    timezone: Timezone;
    /**
     * 
     * @type {CountryCode}
     * @memberof PointObj
     */
    countryCode?: CountryCode;
    /**
     * 
     * @type {CountryName}
     * @memberof PointObj
     */
    countryName?: CountryName;
    /**
     * 
     * @type {SubdivCode}
     * @memberof PointObj
     */
    subdivCode?: SubdivCode;
    /**
     * 
     * @type {SubdivName}
     * @memberof PointObj
     */
    subdivName?: SubdivName;
    /**
     * 
     * @type {BoundingPoints}
     * @memberof PointObj
     */
    boundingPoints: BoundingPoints;
    /**
     * 
     * @type {Grid}
     * @memberof PointObj
     */
    grid: Grid;
    /**
     * 
     * @type {Elevation}
     * @memberof PointObj
     */
    elevation: Elevation;
}
/**
 * The population as represented in the 2010 census.
 * @export
 */
export type Population = number
/**
 * A postcode string.
 * @export
 */
export type Postcode = string
/**
 * A postcode location metadata object
 * @export
 * @interface PostcodeObj
 */
export interface PostcodeObj {
    /**
     * 
     * @type {Postcode}
     * @memberof PostcodeObj
     */
    postcode: Postcode;
    /**
     * 
     * @type {Latitude}
     * @memberof PostcodeObj
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof PostcodeObj
     */
    longitude: Longitude;
    /**
     * 
     * @type {Timezone}
     * @memberof PostcodeObj
     */
    timezone: Timezone;
    /**
     * 
     * @type {CountryCode}
     * @memberof PostcodeObj
     */
    countryCode: CountryCode;
    /**
     * 
     * @type {CountryName}
     * @memberof PostcodeObj
     */
    countryName: CountryName;
    /**
     * 
     * @type {SubdivCode}
     * @memberof PostcodeObj
     */
    subdivCode?: SubdivCode;
    /**
     * 
     * @type {SubdivName}
     * @memberof PostcodeObj
     */
    subdivName?: SubdivName;
    /**
     * 
     * @type {BoundingPoints}
     * @memberof PostcodeObj
     */
    boundingPoints: BoundingPoints;
    /**
     * 
     * @type {Grid}
     * @memberof PostcodeObj
     */
    grid: Grid;
    /**
     * 
     * @type {Elevation}
     * @memberof PostcodeObj
     */
    elevation: Elevation;
}
/**
 * A list of OnPoint™ points used for interpolation for the Designated Market Area. These points are the OnPoint™ ID closest to the centroid of the 10 most populous  postcodes within the target DMA.
 * @export
 */
export type SamplePoints = Array<SamplePointsInner>
/**
 * 
 * @export
 * @interface SamplePointsInner
 */
export interface SamplePointsInner {
    /**
     * 
     * @type {OnpointId}
     * @memberof SamplePointsInner
     */
    onpointId: OnpointId;
    /**
     * 
     * @type {Latitude}
     * @memberof SamplePointsInner
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof SamplePointsInner
     */
    longitude: Longitude;
    /**
     * 
     * @type {Grid}
     * @memberof SamplePointsInner
     */
    grid: Grid;
    /**
     * 
     * @type {DistancePop}
     * @memberof SamplePointsInner
     */
    distance: DistancePop;
    /**
     * 
     * @type {Elevation}
     * @memberof SamplePointsInner
     */
    elevation: Elevation;
}
/**
 * An ISO 3166-2 country subdivision code.
 * @export
 */
export type SubdivCode = string
/**
 * A common country subdivision name.
 * @export
 */
export type SubdivName = string
/**
 * Azimuth of the Sun in degrees, angle along the local horizon measured clockwise from due north.
 * @export
 */
export type SunAzimuth = number
/**
 * Distance from Earth to Sun in miles (imperial) or km (metric, si).
 * @export
 */
export type SunDistance = number
/**
 * Altitude of the Sun in degrees, angle between the horizon and the center of the Sun's disc.
 * @export
 */
export type SunElevation = number
/**
 * Apparent angular radius of the Sun.
 * @export
 */
export type SunRadius = number
/**
 * Time of Sun's transit (solar noon) formatted RFC 3339.
 * @export
 */
export type SunTransit = Date
/**
 * Time of sunrise formatted RFC 3339.
 * @export
 */
export type Sunrise = Date
/**
 * Time of sunset formatted RFC 3339.
 * @export
 */
export type Sunset = Date
/**
 * A timestamp formatted as an RFC3339 date-time value.
 * @export
 */
export type Timestamp = Date
/**
 * An end timestamp for a timestamp range formatted as an RFC3339 date-time value.
 * @export
 */
export type TimestampEnd = Date
/**
 * A timestamp range object
 * @export
 * @interface TimestampRangeObj
 */
export interface TimestampRangeObj {
    /**
     * 
     * @type {TimestampStart}
     * @memberof TimestampRangeObj
     */
    timestampStart: TimestampStart;
    /**
     * 
     * @type {TimestampEnd}
     * @memberof TimestampRangeObj
     */
    timestampEnd: TimestampEnd;
}
/**
 * A start timestamp for a timestamp range formatted as an RFC3339 date-time value.
 * @export
 */
export type TimestampStart = Date
/**
 * An Olson timezone ID.
 * @export
 */
export type Timezone = string
/**
 * DmasApi - fetch parameter creator
 * @export
 */
export const DmasApiFetchParamCreator = function (configuration?: Configuration) {
    return {
        /**
         * Returns a single day of astronomical data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'dmaId' is not null or undefined
            if (dmaId === null || dmaId === undefined) {
                throw new RequiredError('dmaId','Required parameter dmaId was null or undefined when calling dmasDmaIdDaysDateGet.');
            }
            // verify required parameter 'date' is not null or undefined
            if (date === null || date === undefined) {
                throw new RequiredError('date','Required parameter date was null or undefined when calling dmasDmaIdDaysDateGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling dmasDmaIdDaysDateGet.');
            }
            const localVarPath = `/dmas/{dmaId}/days/{date}`
                .replace(`{${"dmaId"}}`, encodeURIComponent(String(dmaId)))
                .replace(`{${"date"}}`, encodeURIComponent(String(date)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of daily astronomical data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'dmaId' is not null or undefined
            if (dmaId === null || dmaId === undefined) {
                throw new RequiredError('dmaId','Required parameter dmaId was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateStart' is not null or undefined
            if (dateStart === null || dateStart === undefined) {
                throw new RequiredError('dateStart','Required parameter dateStart was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateEnd' is not null or undefined
            if (dateEnd === null || dateEnd === undefined) {
                throw new RequiredError('dateEnd','Required parameter dateEnd was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
            }
            const localVarPath = `/dmas/{dmaId}/days/{dateStart},{dateEnd}`
                .replace(`{${"dmaId"}}`, encodeURIComponent(String(dmaId)))
                .replace(`{${"dateStart"}}`, encodeURIComponent(String(dateStart)))
                .replace(`{${"dateEnd"}}`, encodeURIComponent(String(dateEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a single hour of astronomical data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for a DMA
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'dmaId' is not null or undefined
            if (dmaId === null || dmaId === undefined) {
                throw new RequiredError('dmaId','Required parameter dmaId was null or undefined when calling dmasDmaIdHoursTimestampGet.');
            }
            // verify required parameter 'timestamp' is not null or undefined
            if (timestamp === null || timestamp === undefined) {
                throw new RequiredError('timestamp','Required parameter timestamp was null or undefined when calling dmasDmaIdHoursTimestampGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling dmasDmaIdHoursTimestampGet.');
            }
            const localVarPath = `/dmas/{dmaId}/hours/{timestamp}`
                .replace(`{${"dmaId"}}`, encodeURIComponent(String(dmaId)))
                .replace(`{${"timestamp"}}`, encodeURIComponent(String(timestamp)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of hourly astronomical data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'dmaId' is not null or undefined
            if (dmaId === null || dmaId === undefined) {
                throw new RequiredError('dmaId','Required parameter dmaId was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampStart' is not null or undefined
            if (timestampStart === null || timestampStart === undefined) {
                throw new RequiredError('timestampStart','Required parameter timestampStart was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampEnd' is not null or undefined
            if (timestampEnd === null || timestampEnd === undefined) {
                throw new RequiredError('timestampEnd','Required parameter timestampEnd was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
            }
            const localVarPath = `/dmas/{dmaId}/hours/{timestampStart},{timestampEnd}`
                .replace(`{${"dmaId"}}`, encodeURIComponent(String(dmaId)))
                .replace(`{${"timestampStart"}}`, encodeURIComponent(String(timestampStart)))
                .replace(`{${"timestampEnd"}}`, encodeURIComponent(String(timestampEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
    }
};

/**
 * DmasApi - functional programming interface
 * @export
 */
export const DmasApiFp = function(configuration?: Configuration) {
    return {
        /**
         * Returns a single day of astronomical data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyDmaDayObj> {
            const localVarFetchArgs = DmasApiFetchParamCreator(configuration).dmasDmaIdDaysDateGet(dmaId, date, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of daily astronomical data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyDmaDayObj> {
            const localVarFetchArgs = DmasApiFetchParamCreator(configuration).dmasDmaIdDaysDateStartdateEndGet(dmaId, dateStart, dateEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a single hour of astronomical data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for a DMA
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyDmaHourObj> {
            const localVarFetchArgs = DmasApiFetchParamCreator(configuration).dmasDmaIdHoursTimestampGet(dmaId, timestamp, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of hourly astronomical data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyDmaHourObj> {
            const localVarFetchArgs = DmasApiFetchParamCreator(configuration).dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId, timestampStart, timestampEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
    }
};

/**
 * DmasApi - factory interface
 * @export
 */
export const DmasApiFactory = function (configuration?: Configuration, fetch?: FetchAPI, basePath?: string) {
    return {
        /**
         * Returns a single day of astronomical data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
            return DmasApiFp(configuration).dmasDmaIdDaysDateGet(dmaId, date, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of daily astronomical data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
            return DmasApiFp(configuration).dmasDmaIdDaysDateStartdateEndGet(dmaId, dateStart, dateEnd, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a single hour of astronomical data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for a DMA
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return DmasApiFp(configuration).dmasDmaIdHoursTimestampGet(dmaId, timestamp, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of hourly astronomical data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return DmasApiFp(configuration).dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId, timestampStart, timestampEnd, fields, unitScale, options)(fetch, basePath);
        },
    };
};

/**
 * DmasApi - object-oriented interface
 * @export
 * @class DmasApi
 * @extends {BaseAPI}
 */
export class DmasApi extends BaseAPI {
    /**
     * Returns a single day of astronomical data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A day of astronomy data for a DMA.
     * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param {string} date An date formatted as a RFC3339 date value.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DmasApi
     */
    public dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
        return DmasApiFp(this.configuration).dmasDmaIdDaysDateGet(dmaId, date, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of daily astronomical data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of daily astronomy for a DMA.
     * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
     * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DmasApi
     */
    public dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
        return DmasApiFp(this.configuration).dmasDmaIdDaysDateStartdateEndGet(dmaId, dateStart, dateEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a single hour of astronomical data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary An hour of astronomy data for a DMA
     * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DmasApi
     */
    public dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return DmasApiFp(this.configuration).dmasDmaIdHoursTimestampGet(dmaId, timestamp, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of hourly astronomical data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of hourly astronomy for a DMA.
     * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
     * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DmasApi
     */
    public dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return DmasApiFp(this.configuration).dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId, timestampStart, timestampEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

}
/**
 * OnpointsApi - fetch parameter creator
 * @export
 */
export const OnpointsApiFetchParamCreator = function (configuration?: Configuration) {
    return {
        /**
         * Returns a single day of astronomical data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateGet(onpointId: number, date: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'onpointId' is not null or undefined
            if (onpointId === null || onpointId === undefined) {
                throw new RequiredError('onpointId','Required parameter onpointId was null or undefined when calling onpointsOnpointIdDaysDateGet.');
            }
            // verify required parameter 'date' is not null or undefined
            if (date === null || date === undefined) {
                throw new RequiredError('date','Required parameter date was null or undefined when calling onpointsOnpointIdDaysDateGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling onpointsOnpointIdDaysDateGet.');
            }
            const localVarPath = `/onpoints/{onpointId}/days/{date}`
                .replace(`{${"onpointId"}}`, encodeURIComponent(String(onpointId)))
                .replace(`{${"date"}}`, encodeURIComponent(String(date)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of daily astronomical data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateStartdateEndGet(onpointId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'onpointId' is not null or undefined
            if (onpointId === null || onpointId === undefined) {
                throw new RequiredError('onpointId','Required parameter onpointId was null or undefined when calling onpointsOnpointIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateStart' is not null or undefined
            if (dateStart === null || dateStart === undefined) {
                throw new RequiredError('dateStart','Required parameter dateStart was null or undefined when calling onpointsOnpointIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateEnd' is not null or undefined
            if (dateEnd === null || dateEnd === undefined) {
                throw new RequiredError('dateEnd','Required parameter dateEnd was null or undefined when calling onpointsOnpointIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling onpointsOnpointIdDaysDateStartdateEndGet.');
            }
            const localVarPath = `/onpoints/{onpointId}/days/{dateStart},{dateEnd}`
                .replace(`{${"onpointId"}}`, encodeURIComponent(String(onpointId)))
                .replace(`{${"dateStart"}}`, encodeURIComponent(String(dateStart)))
                .replace(`{${"dateEnd"}}`, encodeURIComponent(String(dateEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a single hour of astronomical data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampGet(onpointId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'onpointId' is not null or undefined
            if (onpointId === null || onpointId === undefined) {
                throw new RequiredError('onpointId','Required parameter onpointId was null or undefined when calling onpointsOnpointIdHoursTimestampGet.');
            }
            // verify required parameter 'timestamp' is not null or undefined
            if (timestamp === null || timestamp === undefined) {
                throw new RequiredError('timestamp','Required parameter timestamp was null or undefined when calling onpointsOnpointIdHoursTimestampGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling onpointsOnpointIdHoursTimestampGet.');
            }
            const localVarPath = `/onpoints/{onpointId}/hours/{timestamp}`
                .replace(`{${"onpointId"}}`, encodeURIComponent(String(onpointId)))
                .replace(`{${"timestamp"}}`, encodeURIComponent(String(timestamp)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of hourly astronomical data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'onpointId' is not null or undefined
            if (onpointId === null || onpointId === undefined) {
                throw new RequiredError('onpointId','Required parameter onpointId was null or undefined when calling onpointsOnpointIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampStart' is not null or undefined
            if (timestampStart === null || timestampStart === undefined) {
                throw new RequiredError('timestampStart','Required parameter timestampStart was null or undefined when calling onpointsOnpointIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampEnd' is not null or undefined
            if (timestampEnd === null || timestampEnd === undefined) {
                throw new RequiredError('timestampEnd','Required parameter timestampEnd was null or undefined when calling onpointsOnpointIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling onpointsOnpointIdHoursTimestampStarttimestampEndGet.');
            }
            const localVarPath = `/onpoints/{onpointId}/hours/{timestampStart},{timestampEnd}`
                .replace(`{${"onpointId"}}`, encodeURIComponent(String(onpointId)))
                .replace(`{${"timestampStart"}}`, encodeURIComponent(String(timestampStart)))
                .replace(`{${"timestampEnd"}}`, encodeURIComponent(String(timestampEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
    }
};

/**
 * OnpointsApi - functional programming interface
 * @export
 */
export const OnpointsApiFp = function(configuration?: Configuration) {
    return {
        /**
         * Returns a single day of astronomical data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateGet(onpointId: number, date: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyOnpointDayObj> {
            const localVarFetchArgs = OnpointsApiFetchParamCreator(configuration).onpointsOnpointIdDaysDateGet(onpointId, date, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of daily astronomical data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateStartdateEndGet(onpointId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyOnpointDayObj> {
            const localVarFetchArgs = OnpointsApiFetchParamCreator(configuration).onpointsOnpointIdDaysDateStartdateEndGet(onpointId, dateStart, dateEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a single hour of astronomical data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampGet(onpointId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyOnpointHourObj> {
            const localVarFetchArgs = OnpointsApiFetchParamCreator(configuration).onpointsOnpointIdHoursTimestampGet(onpointId, timestamp, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of hourly astronomical data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyOnpointHourObj> {
            const localVarFetchArgs = OnpointsApiFetchParamCreator(configuration).onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId, timestampStart, timestampEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
    }
};

/**
 * OnpointsApi - factory interface
 * @export
 */
export const OnpointsApiFactory = function (configuration?: Configuration, fetch?: FetchAPI, basePath?: string) {
    return {
        /**
         * Returns a single day of astronomical data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateGet(onpointId: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
            return OnpointsApiFp(configuration).onpointsOnpointIdDaysDateGet(onpointId, date, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of daily astronomical data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateStartdateEndGet(onpointId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
            return OnpointsApiFp(configuration).onpointsOnpointIdDaysDateStartdateEndGet(onpointId, dateStart, dateEnd, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a single hour of astronomical data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampGet(onpointId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return OnpointsApiFp(configuration).onpointsOnpointIdHoursTimestampGet(onpointId, timestamp, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of hourly astronomical data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return OnpointsApiFp(configuration).onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId, timestampStart, timestampEnd, fields, unitScale, options)(fetch, basePath);
        },
    };
};

/**
 * OnpointsApi - object-oriented interface
 * @export
 * @class OnpointsApi
 * @extends {BaseAPI}
 */
export class OnpointsApi extends BaseAPI {
    /**
     * Returns a single day of astronomical data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A day of astronomy data for an OnPoint™ point.
     * @param {number} onpointId An OnPoint™ ID.
     * @param {string} date An date formatted as a RFC3339 date value.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof OnpointsApi
     */
    public onpointsOnpointIdDaysDateGet(onpointId: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
        return OnpointsApiFp(this.configuration).onpointsOnpointIdDaysDateGet(onpointId, date, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of daily astronomical data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of daily astronomy for an OnPoint™ point.
     * @param {number} onpointId An OnPoint™ ID.
     * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
     * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof OnpointsApi
     */
    public onpointsOnpointIdDaysDateStartdateEndGet(onpointId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
        return OnpointsApiFp(this.configuration).onpointsOnpointIdDaysDateStartdateEndGet(onpointId, dateStart, dateEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a single hour of astronomical data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary An hour of astronomy data for an OnPoint™ point.
     * @param {number} onpointId An OnPoint™ ID.
     * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof OnpointsApi
     */
    public onpointsOnpointIdHoursTimestampGet(onpointId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return OnpointsApiFp(this.configuration).onpointsOnpointIdHoursTimestampGet(onpointId, timestamp, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of hourly astronomical data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of hourly astronomy for an OnPoint™ point.
     * @param {number} onpointId An OnPoint™ ID.
     * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
     * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof OnpointsApi
     */
    public onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return OnpointsApiFp(this.configuration).onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId, timestampStart, timestampEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

}
/**
 * PointsApi - fetch parameter creator
 * @export
 */
export const PointsApiFetchParamCreator = function (configuration?: Configuration) {
    return {
        /**
         * Returns a single day of astronomical data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'latitude' is not null or undefined
            if (latitude === null || latitude === undefined) {
                throw new RequiredError('latitude','Required parameter latitude was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
            }
            // verify required parameter 'longitude' is not null or undefined
            if (longitude === null || longitude === undefined) {
                throw new RequiredError('longitude','Required parameter longitude was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
            }
            // verify required parameter 'date' is not null or undefined
            if (date === null || date === undefined) {
                throw new RequiredError('date','Required parameter date was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
            }
            const localVarPath = `/points/{latitude},{longitude}/days/{date}`
                .replace(`{${"latitude"}}`, encodeURIComponent(String(latitude)))
                .replace(`{${"longitude"}}`, encodeURIComponent(String(longitude)))
                .replace(`{${"date"}}`, encodeURIComponent(String(date)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of daily astronomical data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'latitude' is not null or undefined
            if (latitude === null || latitude === undefined) {
                throw new RequiredError('latitude','Required parameter latitude was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'longitude' is not null or undefined
            if (longitude === null || longitude === undefined) {
                throw new RequiredError('longitude','Required parameter longitude was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateStart' is not null or undefined
            if (dateStart === null || dateStart === undefined) {
                throw new RequiredError('dateStart','Required parameter dateStart was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateEnd' is not null or undefined
            if (dateEnd === null || dateEnd === undefined) {
                throw new RequiredError('dateEnd','Required parameter dateEnd was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
            }
            const localVarPath = `/points/{latitude},{longitude}/days/{dateStart},{dateEnd}`
                .replace(`{${"latitude"}}`, encodeURIComponent(String(latitude)))
                .replace(`{${"longitude"}}`, encodeURIComponent(String(longitude)))
                .replace(`{${"dateStart"}}`, encodeURIComponent(String(dateStart)))
                .replace(`{${"dateEnd"}}`, encodeURIComponent(String(dateEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a single hour of astronomical data for a Latitude/Longitude point.  **IMPORTANT:** To authorize requests, an API key must be provided as a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'latitude' is not null or undefined
            if (latitude === null || latitude === undefined) {
                throw new RequiredError('latitude','Required parameter latitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
            }
            // verify required parameter 'longitude' is not null or undefined
            if (longitude === null || longitude === undefined) {
                throw new RequiredError('longitude','Required parameter longitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
            }
            // verify required parameter 'timestamp' is not null or undefined
            if (timestamp === null || timestamp === undefined) {
                throw new RequiredError('timestamp','Required parameter timestamp was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
            }
            const localVarPath = `/points/{latitude},{longitude}/hours/{timestamp}`
                .replace(`{${"latitude"}}`, encodeURIComponent(String(latitude)))
                .replace(`{${"longitude"}}`, encodeURIComponent(String(longitude)))
                .replace(`{${"timestamp"}}`, encodeURIComponent(String(timestamp)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of hourly astronomical data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'latitude' is not null or undefined
            if (latitude === null || latitude === undefined) {
                throw new RequiredError('latitude','Required parameter latitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'longitude' is not null or undefined
            if (longitude === null || longitude === undefined) {
                throw new RequiredError('longitude','Required parameter longitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampStart' is not null or undefined
            if (timestampStart === null || timestampStart === undefined) {
                throw new RequiredError('timestampStart','Required parameter timestampStart was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampEnd' is not null or undefined
            if (timestampEnd === null || timestampEnd === undefined) {
                throw new RequiredError('timestampEnd','Required parameter timestampEnd was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
            }
            const localVarPath = `/points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd}`
                .replace(`{${"latitude"}}`, encodeURIComponent(String(latitude)))
                .replace(`{${"longitude"}}`, encodeURIComponent(String(longitude)))
                .replace(`{${"timestampStart"}}`, encodeURIComponent(String(timestampStart)))
                .replace(`{${"timestampEnd"}}`, encodeURIComponent(String(timestampEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
    }
};

/**
 * PointsApi - functional programming interface
 * @export
 */
export const PointsApiFp = function(configuration?: Configuration) {
    return {
        /**
         * Returns a single day of astronomical data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyPointDayObj> {
            const localVarFetchArgs = PointsApiFetchParamCreator(configuration).pointsLatitudelongitudeDaysDateGet(latitude, longitude, date, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of daily astronomical data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyPointDayObj> {
            const localVarFetchArgs = PointsApiFetchParamCreator(configuration).pointsLatitudelongitudeDaysDateStartdateEndGet(latitude, longitude, dateStart, dateEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a single hour of astronomical data for a Latitude/Longitude point.  **IMPORTANT:** To authorize requests, an API key must be provided as a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyPointHourObj> {
            const localVarFetchArgs = PointsApiFetchParamCreator(configuration).pointsLatitudelongitudeHoursTimestampGet(latitude, longitude, timestamp, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of hourly astronomical data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyPointHourObj> {
            const localVarFetchArgs = PointsApiFetchParamCreator(configuration).pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude, longitude, timestampStart, timestampEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
    }
};

/**
 * PointsApi - factory interface
 * @export
 */
export const PointsApiFactory = function (configuration?: Configuration, fetch?: FetchAPI, basePath?: string) {
    return {
        /**
         * Returns a single day of astronomical data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
            return PointsApiFp(configuration).pointsLatitudelongitudeDaysDateGet(latitude, longitude, date, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of daily astronomical data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
            return PointsApiFp(configuration).pointsLatitudelongitudeDaysDateStartdateEndGet(latitude, longitude, dateStart, dateEnd, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a single hour of astronomical data for a Latitude/Longitude point.  **IMPORTANT:** To authorize requests, an API key must be provided as a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return PointsApiFp(configuration).pointsLatitudelongitudeHoursTimestampGet(latitude, longitude, timestamp, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of hourly astronomical data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return PointsApiFp(configuration).pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude, longitude, timestampStart, timestampEnd, fields, unitScale, options)(fetch, basePath);
        },
    };
};

/**
 * PointsApi - object-oriented interface
 * @export
 * @class PointsApi
 * @extends {BaseAPI}
 */
export class PointsApi extends BaseAPI {
    /**
     * Returns a single day of astronomical data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A day of astronomy data for a Latitude/Longitude point.
     * @param {number} latitude A latitude value between -90° and 90°.
     * @param {number} longitude A longitude value between -180° (West) and 180° (East).
     * @param {string} date An date formatted as a RFC3339 date value.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PointsApi
     */
    public pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
        return PointsApiFp(this.configuration).pointsLatitudelongitudeDaysDateGet(latitude, longitude, date, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of daily astronomical data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of daily astronomy for a Latitude/Longitude point.
     * @param {number} latitude A latitude value between -90° and 90°.
     * @param {number} longitude A longitude value between -180° (West) and 180° (East).
     * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
     * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PointsApi
     */
    public pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
        return PointsApiFp(this.configuration).pointsLatitudelongitudeDaysDateStartdateEndGet(latitude, longitude, dateStart, dateEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a single hour of astronomical data for a Latitude/Longitude point.  **IMPORTANT:** To authorize requests, an API key must be provided as a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary An hour of astronomy data for a Latitude/Longitude point.
     * @param {number} latitude A latitude value between -90° and 90°.
     * @param {number} longitude A longitude value between -180° (West) and 180° (East).
     * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PointsApi
     */
    public pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return PointsApiFp(this.configuration).pointsLatitudelongitudeHoursTimestampGet(latitude, longitude, timestamp, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of hourly astronomical data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of hourly astronomy for a Latitude/Longitude point.
     * @param {number} latitude A latitude value between -90° and 90°.
     * @param {number} longitude A longitude value between -180° (West) and 180° (East).
     * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
     * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PointsApi
     */
    public pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return PointsApiFp(this.configuration).pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude, longitude, timestampStart, timestampEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

}
/**
 * PostcodesApi - fetch parameter creator
 * @export
 */
export const PostcodesApiFetchParamCreator = function (configuration?: Configuration) {
    return {
        /**
         * Returns a single day of astronomical data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateGet(postcode: string, countryCode: string, date: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'postcode' is not null or undefined
            if (postcode === null || postcode === undefined) {
                throw new RequiredError('postcode','Required parameter postcode was null or undefined when calling postcodesPostcodecountryCodeDaysDateGet.');
            }
            // verify required parameter 'countryCode' is not null or undefined
            if (countryCode === null || countryCode === undefined) {
                throw new RequiredError('countryCode','Required parameter countryCode was null or undefined when calling postcodesPostcodecountryCodeDaysDateGet.');
            }
            // verify required parameter 'date' is not null or undefined
            if (date === null || date === undefined) {
                throw new RequiredError('date','Required parameter date was null or undefined when calling postcodesPostcodecountryCodeDaysDateGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling postcodesPostcodecountryCodeDaysDateGet.');
            }
            const localVarPath = `/postcodes/{postcode},{countryCode}/days/{date}`
                .replace(`{${"postcode"}}`, encodeURIComponent(String(postcode)))
                .replace(`{${"countryCode"}}`, encodeURIComponent(String(countryCode)))
                .replace(`{${"date"}}`, encodeURIComponent(String(date)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of daily astronomical data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode: string, countryCode: string, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'postcode' is not null or undefined
            if (postcode === null || postcode === undefined) {
                throw new RequiredError('postcode','Required parameter postcode was null or undefined when calling postcodesPostcodecountryCodeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'countryCode' is not null or undefined
            if (countryCode === null || countryCode === undefined) {
                throw new RequiredError('countryCode','Required parameter countryCode was null or undefined when calling postcodesPostcodecountryCodeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateStart' is not null or undefined
            if (dateStart === null || dateStart === undefined) {
                throw new RequiredError('dateStart','Required parameter dateStart was null or undefined when calling postcodesPostcodecountryCodeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateEnd' is not null or undefined
            if (dateEnd === null || dateEnd === undefined) {
                throw new RequiredError('dateEnd','Required parameter dateEnd was null or undefined when calling postcodesPostcodecountryCodeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling postcodesPostcodecountryCodeDaysDateStartdateEndGet.');
            }
            const localVarPath = `/postcodes/{postcode},{countryCode}/days/{dateStart},{dateEnd}`
                .replace(`{${"postcode"}}`, encodeURIComponent(String(postcode)))
                .replace(`{${"countryCode"}}`, encodeURIComponent(String(countryCode)))
                .replace(`{${"dateStart"}}`, encodeURIComponent(String(dateStart)))
                .replace(`{${"dateEnd"}}`, encodeURIComponent(String(dateEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a single hour of astronomical data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampGet(postcode: string, countryCode: string, timestamp: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'postcode' is not null or undefined
            if (postcode === null || postcode === undefined) {
                throw new RequiredError('postcode','Required parameter postcode was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampGet.');
            }
            // verify required parameter 'countryCode' is not null or undefined
            if (countryCode === null || countryCode === undefined) {
                throw new RequiredError('countryCode','Required parameter countryCode was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampGet.');
            }
            // verify required parameter 'timestamp' is not null or undefined
            if (timestamp === null || timestamp === undefined) {
                throw new RequiredError('timestamp','Required parameter timestamp was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampGet.');
            }
            const localVarPath = `/postcodes/{postcode},{countryCode}/hours/{timestamp}`
                .replace(`{${"postcode"}}`, encodeURIComponent(String(postcode)))
                .replace(`{${"countryCode"}}`, encodeURIComponent(String(countryCode)))
                .replace(`{${"timestamp"}}`, encodeURIComponent(String(timestamp)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of hourly astronomical data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode: string, countryCode: string, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'postcode' is not null or undefined
            if (postcode === null || postcode === undefined) {
                throw new RequiredError('postcode','Required parameter postcode was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'countryCode' is not null or undefined
            if (countryCode === null || countryCode === undefined) {
                throw new RequiredError('countryCode','Required parameter countryCode was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampStart' is not null or undefined
            if (timestampStart === null || timestampStart === undefined) {
                throw new RequiredError('timestampStart','Required parameter timestampStart was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampEnd' is not null or undefined
            if (timestampEnd === null || timestampEnd === undefined) {
                throw new RequiredError('timestampEnd','Required parameter timestampEnd was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet.');
            }
            const localVarPath = `/postcodes/{postcode},{countryCode}/hours/{timestampStart},{timestampEnd}`
                .replace(`{${"postcode"}}`, encodeURIComponent(String(postcode)))
                .replace(`{${"countryCode"}}`, encodeURIComponent(String(countryCode)))
                .replace(`{${"timestampStart"}}`, encodeURIComponent(String(timestampStart)))
                .replace(`{${"timestampEnd"}}`, encodeURIComponent(String(timestampEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
    }
};

/**
 * PostcodesApi - functional programming interface
 * @export
 */
export const PostcodesApiFp = function(configuration?: Configuration) {
    return {
        /**
         * Returns a single day of astronomical data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateGet(postcode: string, countryCode: string, date: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyPostcodeDayObj> {
            const localVarFetchArgs = PostcodesApiFetchParamCreator(configuration).postcodesPostcodecountryCodeDaysDateGet(postcode, countryCode, date, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of daily astronomical data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode: string, countryCode: string, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyPostcodeDayObj> {
            const localVarFetchArgs = PostcodesApiFetchParamCreator(configuration).postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode, countryCode, dateStart, dateEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a single hour of astronomical data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampGet(postcode: string, countryCode: string, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyPostcodeHourObj> {
            const localVarFetchArgs = PostcodesApiFetchParamCreator(configuration).postcodesPostcodecountryCodeHoursTimestampGet(postcode, countryCode, timestamp, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of hourly astronomical data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode: string, countryCode: string, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<AstronomyPostcodeHourObj> {
            const localVarFetchArgs = PostcodesApiFetchParamCreator(configuration).postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode, countryCode, timestampStart, timestampEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
    }
};

/**
 * PostcodesApi - factory interface
 * @export
 */
export const PostcodesApiFactory = function (configuration?: Configuration, fetch?: FetchAPI, basePath?: string) {
    return {
        /**
         * Returns a single day of astronomical data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of astronomy data for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateGet(postcode: string, countryCode: string, date: string, fields: Array<string>, unitScale?: string, options?: any) {
            return PostcodesApiFp(configuration).postcodesPostcodecountryCodeDaysDateGet(postcode, countryCode, date, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of daily astronomical data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily astronomy for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode: string, countryCode: string, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
            return PostcodesApiFp(configuration).postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode, countryCode, dateStart, dateEnd, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a single hour of astronomical data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of astronomy data for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampGet(postcode: string, countryCode: string, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return PostcodesApiFp(configuration).postcodesPostcodecountryCodeHoursTimestampGet(postcode, countryCode, timestamp, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of hourly astronomical data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly astronomy for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode: string, countryCode: string, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return PostcodesApiFp(configuration).postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode, countryCode, timestampStart, timestampEnd, fields, unitScale, options)(fetch, basePath);
        },
    };
};

/**
 * PostcodesApi - object-oriented interface
 * @export
 * @class PostcodesApi
 * @extends {BaseAPI}
 */
export class PostcodesApi extends BaseAPI {
    /**
     * Returns a single day of astronomical data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A day of astronomy data for a postcode.
     * @param {string} postcode A postcode string.
     * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
     * @param {string} date An date formatted as a RFC3339 date value.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PostcodesApi
     */
    public postcodesPostcodecountryCodeDaysDateGet(postcode: string, countryCode: string, date: string, fields: Array<string>, unitScale?: string, options?: any) {
        return PostcodesApiFp(this.configuration).postcodesPostcodecountryCodeDaysDateGet(postcode, countryCode, date, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of daily astronomical data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of daily astronomy for a postcode.
     * @param {string} postcode A postcode string.
     * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
     * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
     * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PostcodesApi
     */
    public postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode: string, countryCode: string, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
        return PostcodesApiFp(this.configuration).postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode, countryCode, dateStart, dateEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a single hour of astronomical data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary An hour of astronomy data for a postcode.
     * @param {string} postcode A postcode string.
     * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
     * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PostcodesApi
     */
    public postcodesPostcodecountryCodeHoursTimestampGet(postcode: string, countryCode: string, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return PostcodesApiFp(this.configuration).postcodesPostcodecountryCodeHoursTimestampGet(postcode, countryCode, timestamp, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of hourly astronomical data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Astronomy API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of hourly astronomy for a postcode.
     * @param {string} postcode A postcode string.
     * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
     * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
     * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PostcodesApi
     */
    public postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode: string, countryCode: string, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return PostcodesApiFp(this.configuration).postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode, countryCode, timestampStart, timestampEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

}
